document.addEventListener('DOMContentLoaded', function() {
  // Smooth scroll for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });

  // Risk assessment functionality
  const jobCategory = document.getElementById('jobCategory');
  const riskMeter = document.querySelector('.meter-fill');
  
  const riskLevels = {
    'creative': 60,
    'technical': 40,
    'service': 85,
    'management': 30,
    'data': 70
  };

  jobCategory.addEventListener('change', function() {
    const selectedJob = this.value;
    if (selectedJob) {
      const riskPercentage = riskLevels[selectedJob];
      riskMeter.style.width = `${riskPercentage}%`;
      riskMeter.style.backgroundColor = getRiskColor(riskPercentage);
    }
  });

  function getRiskColor(percentage) {
    if (percentage >= 70) return '#ff6b6b';
    if (percentage >= 40) return '#ffd93d';
    return '#6bff84';
  }

  // Intersection Observer for fade-in animations
  const observerOptions = {
    threshold: 0.1,
    rootMargin: '0px 0px -50px 0px'
  };

  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.classList.add('visible');
      }
    });
  }, observerOptions);

  document.querySelectorAll('section').forEach(section => {
    section.classList.add('fade-in');
    observer.observe(section);
  });
});
